@@ -19,5 +19,8 @@ options(show.signif.stars = FALSE)
              OrchardSprays, poisson()))
 
 ## Laplace approximation
-(fm4 <- lmer(decrease ~ treatment + (1|rowpos) + (1|colpos),
-                OrchardSprays, poisson(), method = "Laplace"))
+if (FALSE) {
+    (fm4 <- lmer(decrease ~ treatment + (1|rowpos) + (1|colpos),
+                 OrchardSprays, poisson(), method = "Laplace",
+                 control = list(niterEM=30)))
+}
